package Software::License::CC_BY_NC_2_0;

use strict;
use warnings;

use base 'Software::License';

our $AUTHORITY = 'cpan:BBYRD'; # AUTHORITY
our $VERSION = '1.11'; # VERSION
# ABSTRACT: Creative Commons Attribution-NonCommercial 2.0 License (CC BY-NC 2.0)

### NOTE: This file was auto-generated using cc-license.sh.  Do not edit this file!

sub name { 'Creative Commons Attribution-NonCommercial 2.0 License (CC BY-NC 2.0)' }
sub url  { 'http://creativecommons.org/licenses/by-nc/2.0/' }

sub version    { '2.0' }
sub meta_name  { 'restricted' }

1;

=pod

=encoding UTF-8

=head1 NAME

Software::License::CC_BY_NC_2_0 - Creative Commons Attribution-NonCommercial 2.0 License (CC BY-NC 2.0)

=head1 AVAILABILITY

The project homepage is L<https://github.com/SineSwiper/Software-License-CCpack>.

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see L<https://metacpan.org/module/Software::License::CCpack/>.

=head1 AUTHOR

Brendan Byrd <BBYRD@CPAN.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2014 by Brendan Byrd.

This is free software, licensed under:

  The GNU Lesser General Public License, Version 3, June 2007

=cut

__DATA__
__NOTICE__
This work, created by {{$self->holder}}, is licensed under a
Creative Commons Attribution-NonCommercial 2.0 License.

You are free to:

   * Share -- copy and redistribute the material in any medium or format

   * Adapt -- remix, transform, and build upon the material

   * The licensor cannot revoke these freedoms as long as you follow the
     license terms.

Under the following terms:

   * Attribution -- You must give appropriate credit, provide a link to the
     license, and indicate if changes were made. You may do so in any
     reasonable manner, but not in any way that suggests the licensor
     endorses you or your use.

   * No additional restrictions -- You may not apply legal terms or
     technological measures that legally restrict others from doing
     anything the license permits.

Notices:

   * You do not have to comply with the license for elements of the
     material in the public domain or where your use is permitted by an
     applicable exception or limitation.

   * No warranties are given. The license may not give you all of the
     permissions necessary for your intended use. For example, other rights
     such as publicity, privacy, or moral rights may limit how you use the
     material.
__LICENSE__
                                Creative Commons

                          Creative Commons Legal Code

                         Attribution-NonCommercial 2.0

   CREATIVE COMMONS CORPORATION IS NOT A LAW FIRM AND DOES NOT PROVIDE LEGAL
   SERVICES. DISTRIBUTION OF THIS LICENSE DOES NOT CREATE AN ATTORNEY-CLIENT
   RELATIONSHIP. CREATIVE COMMONS PROVIDES THIS INFORMATION ON AN "AS-IS"
   BASIS. CREATIVE COMMONS MAKES NO WARRANTIES REGARDING THE INFORMATION
   PROVIDED, AND DISCLAIMS LIABILITY FOR DAMAGES RESULTING FROM ITS USE.

   License

   THE WORK (AS DEFINED BELOW) IS PROVIDED UNDER THE TERMS OF THIS CREATIVE
   COMMONS PUBLIC LICENSE ("CCPL" OR "LICENSE"). THE WORK IS PROTECTED BY
   COPYRIGHT AND/OR OTHER APPLICABLE LAW. ANY USE OF THE WORK OTHER THAN AS
   AUTHORIZED UNDER THIS LICENSE OR COPYRIGHT LAW IS PROHIBITED.

   BY EXERCISING ANY RIGHTS TO THE WORK PROVIDED HERE, YOU ACCEPT AND AGREE
   TO BE BOUND BY THE TERMS OF THIS LICENSE. THE LICENSOR GRANTS YOU THE
   RIGHTS CONTAINED HERE IN CONSIDERATION OF YOUR ACCEPTANCE OF SUCH TERMS
   AND CONDITIONS.

   1. Definitions

    a. "Collective Work" means a work, such as a periodical issue, anthology
       or encyclopedia, in which the Work in its entirety in unmodified form,
       along with a number of other contributions, constituting separate and
       independent works in themselves, are assembled into a collective
       whole. A work that constitutes a Collective Work will not be
       considered a Derivative Work (as defined below) for the purposes of
       this License.

    b. "Derivative Work" means a work based upon the Work or upon the Work
       and other pre-existing works, such as a translation, musical
       arrangement, dramatization, fictionalization, motion picture version,
       sound recording, art reproduction, abridgment, condensation, or any
       other form in which the Work may be recast, transformed, or adapted,
       except that a work that constitutes a Collective Work will not be
       considered a Derivative Work for the purpose of this License. For the
       avoidance of doubt, where the Work is a musical composition or sound
       recording, the synchronization of the Work in timed-relation with a
       moving image ("synching") will be considered a Derivative Work for the
       purpose of this License.

    c. "Licensor" means the individual or entity that offers the Work under
       the terms of this License.

    d. "Original Author" means the individual or entity who created the Work.

    e. "Work" means the copyrightable work of authorship offered under the
       terms of this License.

    f. "You" means an individual or entity exercising rights under this
       License who has not previously violated the terms of this License with
       respect to the Work, or who has received express permission from the
       Licensor to exercise rights under this License despite a previous
       violation.

   2. Fair Use Rights. Nothing in this license is intended to reduce, limit,
   or restrict any rights arising from fair use, first sale or other
   limitations on the exclusive rights of the copyright owner under copyright
   law or other applicable laws.

   3. License Grant. Subject to the terms and conditions of this License,
   Licensor hereby grants You a worldwide, royalty-free, non-exclusive,
   perpetual (for the duration of the applicable copyright) license to
   exercise the rights in the Work as stated below:

    a. to reproduce the Work, to incorporate the Work into one or more
       Collective Works, and to reproduce the Work as incorporated in the
       Collective Works;

    b. to create and reproduce Derivative Works;

    c. to distribute copies or phonorecords of, display publicly, perform
       publicly, and perform publicly by means of a digital audio
       transmission the Work including as incorporated in Collective Works;

    d. to distribute copies or phonorecords of, display publicly, perform
       publicly, and perform publicly by means of a digital audio
       transmission Derivative Works;

   The above rights may be exercised in all media and formats whether now
   known or hereafter devised. The above rights include the right to make
   such modifications as are technically necessary to exercise the rights in
   other media and formats. All rights not expressly granted by Licensor are
   hereby reserved, including but not limited to the rights set forth in
   Sections 4(d) and 4(e).

   4. Restrictions.The license granted in Section 3 above is expressly made
   subject to and limited by the following restrictions:

    a. You may distribute, publicly display, publicly perform, or publicly
       digitally perform the Work only under the terms of this License, and
       You must include a copy of, or the Uniform Resource Identifier for,
       this License with every copy or phonorecord of the Work You
       distribute, publicly display, publicly perform, or publicly digitally
       perform. You may not offer or impose any terms on the Work that alter
       or restrict the terms of this License or the recipients' exercise of
       the rights granted hereunder. You may not sublicense the Work. You
       must keep intact all notices that refer to this License and to the
       disclaimer of warranties. You may not distribute, publicly display,
       publicly perform, or publicly digitally perform the Work with any
       technological measures that control access or use of the Work in a
       manner inconsistent with the terms of this License Agreement. The
       above applies to the Work as incorporated in a Collective Work, but
       this does not require the Collective Work apart from the Work itself
       to be made subject to the terms of this License. If You create a
       Collective Work, upon notice from any Licensor You must, to the extent
       practicable, remove from the Collective Work any reference to such
       Licensor or the Original Author, as requested. If You create a
       Derivative Work, upon notice from any Licensor You must, to the extent
       practicable, remove from the Derivative Work any reference to such
       Licensor or the Original Author, as requested.

    b. You may not exercise any of the rights granted to You in Section 3
       above in any manner that is primarily intended for or directed toward
       commercial advantage or private monetary compensation. The exchange of
       the Work for other copyrighted works by means of digital file-sharing
       or otherwise shall not be considered to be intended for or directed
       toward commercial advantage or private monetary compensation, provided
       there is no payment of any monetary compensation in connection with
       the exchange of copyrighted works.

    c. If you distribute, publicly display, publicly perform, or publicly
       digitally perform the Work or any Derivative Works or Collective
       Works, You must keep intact all copyright notices for the Work and
       give the Original Author credit reasonable to the medium or means You
       are utilizing by conveying the name (or pseudonym if applicable) of
       the Original Author if supplied; the title of the Work if supplied; to
       the extent reasonably practicable, the Uniform Resource Identifier, if
       any, that Licensor specifies to be associated with the Work, unless
       such URI does not refer to the copyright notice or licensing
       information for the Work; and in the case of a Derivative Work, a
       credit identifying the use of the Work in the Derivative Work (e.g.,
       "French translation of the Work by Original Author," or "Screenplay
       based on original Work by Original Author"). Such credit may be
       implemented in any reasonable manner; provided, however, that in the
       case of a Derivative Work or Collective Work, at a minimum such credit
       will appear where any other comparable authorship credit appears and
       in a manner at least as prominent as such other comparable authorship
       credit.

    d. For the avoidance of doubt, where the Work is a musical composition:

         i. Performance Royalties Under Blanket Licenses. Licensor reserves
            the exclusive right to collect, whether individually or via a
            performance rights society (e.g. ASCAP, BMI, SESAC), royalties
            for the public performance or public digital performance (e.g.
            webcast) of the Work if that performance is primarily intended
            for or directed toward commercial advantage or private monetary
            compensation.

        ii. Mechanical Rights and Statutory Royalties. Licensor reserves the
            exclusive right to collect, whether individually or via a music
            rights agency or designated agent (e.g. Harry Fox Agency),
            royalties for any phonorecord You create from the Work ("cover
            version") and distribute, subject to the compulsory license
            created by 17 USC Section 115 of the US Copyright Act (or the
            equivalent in other jurisdictions), if Your distribution of such
            cover version is primarily intended for or directed toward
            commercial advantage or private monetary compensation.

    e. Webcasting Rights and Statutory Royalties. For the avoidance of doubt,
       where the Work is a sound recording, Licensor reserves the exclusive
       right to collect, whether individually or via a performance-rights
       society (e.g. SoundExchange), royalties for the public digital
       performance (e.g. webcast) of the Work, subject to the compulsory
       license created by 17 USC Section 114 of the US Copyright Act (or the
       equivalent in other jurisdictions), if Your public digital performance
       is primarily intended for or directed toward commercial advantage or
       private monetary compensation.

   5. Representations, Warranties and Disclaimer

   UNLESS OTHERWISE MUTUALLY AGREED TO BY THE PARTIES IN WRITING, LICENSOR
   OFFERS THE WORK AS-IS AND MAKES NO REPRESENTATIONS OR WARRANTIES OF ANY
   KIND CONCERNING THE WORK, EXPRESS, IMPLIED, STATUTORY OR OTHERWISE,
   INCLUDING, WITHOUT LIMITATION, WARRANTIES OF TITLE, MERCHANTIBILITY,
   FITNESS FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF
   LATENT OR OTHER DEFECTS, ACCURACY, OR THE PRESENCE OF ABSENCE OF ERRORS,
   WHETHER OR NOT DISCOVERABLE. SOME JURISDICTIONS DO NOT ALLOW THE EXCLUSION
   OF IMPLIED WARRANTIES, SO SUCH EXCLUSION MAY NOT APPLY TO YOU.

   6. Limitation on Liability. EXCEPT TO THE EXTENT REQUIRED BY APPLICABLE
   LAW, IN NO EVENT WILL LICENSOR BE LIABLE TO YOU ON ANY LEGAL THEORY FOR
   ANY SPECIAL, INCIDENTAL, CONSEQUENTIAL, PUNITIVE OR EXEMPLARY DAMAGES
   ARISING OUT OF THIS LICENSE OR THE USE OF THE WORK, EVEN IF LICENSOR HAS
   BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

   7. Termination

    a. This License and the rights granted hereunder will terminate
       automatically upon any breach by You of the terms of this License.
       Individuals or entities who have received Derivative Works or
       Collective Works from You under this License, however, will not have
       their licenses terminated provided such individuals or entities remain
       in full compliance with those licenses. Sections 1, 2, 5, 6, 7, and 8
       will survive any termination of this License.

    b. Subject to the above terms and conditions, the license granted here is
       perpetual (for the duration of the applicable copyright in the Work).
       Notwithstanding the above, Licensor reserves the right to release the
       Work under different license terms or to stop distributing the Work at
       any time; provided, however that any such election will not serve to
       withdraw this License (or any other license that has been, or is
       required to be, granted under the terms of this License), and this
       License will continue in full force and effect unless terminated as
       stated above.

   8. Miscellaneous

    a. Each time You distribute or publicly digitally perform the Work or a
       Collective Work, the Licensor offers to the recipient a license to the
       Work on the same terms and conditions as the license granted to You
       under this License.

    b. Each time You distribute or publicly digitally perform a Derivative
       Work, Licensor offers to the recipient a license to the original Work
       on the same terms and conditions as the license granted to You under
       this License.

    c. If any provision of this License is invalid or unenforceable under
       applicable law, it shall not affect the validity or enforceability of
       the remainder of the terms of this License, and without further action
       by the parties to this agreement, such provision shall be reformed to
       the minimum extent necessary to make such provision valid and
       enforceable.

    d. No term or provision of this License shall be deemed waived and no
       breach consented to unless such waiver or consent shall be in writing
       and signed by the party to be charged with such waiver or consent.

    e. This License constitutes the entire agreement between the parties with
       respect to the Work licensed here. There are no understandings,
       agreements or representations with respect to the Work not specified
       here. Licensor shall not be bound by any additional provisions that
       may appear in any communication from You. This License may not be
       modified without the mutual written agreement of the Licensor and You.
