package Software::License::CC_PDM_1_0;

use strict;
use warnings;

use base 'Software::License';

our $AUTHORITY = 'cpan:BBYRD'; # AUTHORITY
our $VERSION = '1.11'; # VERSION
# ABSTRACT: Creative Commons Public Domain Mark 1.0

### NOTE: This file was auto-generated using cc-pdmark.sh.  Do not edit this file!

sub name { 'Creative Commons Public Domain Mark 1.0' }
sub url  { 'http://creativecommons.org/publicdomain/mark/1.0/' }

sub version    { '1.0' }
sub meta_name  { 'unrestricted' }

1;

=pod

=encoding UTF-8

=head1 NAME

Software::License::CC_PDM_1_0 - Creative Commons Public Domain Mark 1.0

=head1 AVAILABILITY

The project homepage is L<https://github.com/SineSwiper/Software-License-CCpack>.

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see L<https://metacpan.org/module/Software::License::CCpack/>.

=head1 AUTHOR

Brendan Byrd <BBYRD@CPAN.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2014 by Brendan Byrd.

This is free software, licensed under:

  The GNU Lesser General Public License, Version 3, June 2007

=cut

__DATA__
__LICENSE__
Public Domain Mark 1.0

No Copyright

   * This work has been identified as being free of known restrictions under
     copyright law, including all related and neighboring rights.

   * You can copy, modify, distribute and perform the work, even for
     commercial purposes, all without asking permission. See Other
     Information below.

   * Other Information

      + The work may not be free of known copyright restrictions in all
        jurisdictions.

      + Persons may have other rights in or related to the work, such as
        patent or trademark rights, and others may have rights in how the
        work is used, such as publicity or privacy rights.

      + In some jurisdictions moral rights of the author may persist beyond
        the term of copyright. These rights may include the right to be
        identified as the author and the right to object to derogatory
        treatments.

      + Unless expressly stated otherwise, the person who identified the
        work makes no warranties about the work, and disclaims liability
        for all uses of the work, to the fullest extent permitted by
        applicable law.

      + When using or citing the work, you should not imply endorsement by
        the author or the person who identified the work.
